Class: Pikuri::Mcp::Registry::StdioEntry

Inherits:
Data
  • Object
show all
Defined in:
lib/pikuri/mcp/registry.rb

Overview

One local-subprocess MCP server’s configuration: a unique id (used by the LLM to call mcp_connect) and the argv array used to spawn the server process.

command is an argv array (not a shell string) to align with Subprocess.spawn conventions even though the mcp gem owns the actual spawn — see CLAUDE.md “Subprocess seam” carve-out. First element is the executable; remaining elements are arguments.

Instance Attribute Summary collapse

Instance Attribute Details

#commandObject (readonly)

Returns the value of attribute command

Returns:

  • (Object)

    the current value of command



52
# File 'lib/pikuri/mcp/registry.rb', line 52

StdioEntry = Data.define(:id, :command)

#idObject (readonly)

Returns the value of attribute id

Returns:

  • (Object)

    the current value of id



52
# File 'lib/pikuri/mcp/registry.rb', line 52

StdioEntry = Data.define(:id, :command)