Class: Pikuri::Mcp::Registry::StdioEntry
- Inherits:
-
Data
- Object
- Data
- Pikuri::Mcp::Registry::StdioEntry
- Defined in:
- lib/pikuri/mcp/registry.rb
Overview
One local-subprocess MCP server’s configuration: a unique id (used by the LLM to call mcp_connect) and the argv array used to spawn the server process.
command is an argv array (not a shell string) to align with Subprocess.spawn conventions even though the mcp gem owns the actual spawn — see CLAUDE.md “Subprocess seam” carve-out. First element is the executable; remaining elements are arguments.
Instance Attribute Summary collapse
-
#command ⇒ Object
readonly
Returns the value of attribute command.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
Instance Attribute Details
#command ⇒ Object (readonly)
Returns the value of attribute command
52 |
# File 'lib/pikuri/mcp/registry.rb', line 52 StdioEntry = Data.define(:id, :command) |
#id ⇒ Object (readonly)
Returns the value of attribute id
52 |
# File 'lib/pikuri/mcp/registry.rb', line 52 StdioEntry = Data.define(:id, :command) |